@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Any
 
 from .interface import Interface
 
 
-class IPointingAltAz(Interface):
+class IPointingAltAz(Interface, metaclass=ABCMeta):
     """The module can move to Alt/Az coordinates, usually combined with :class:`~pyobs.interfaces.ITelescope`."""
-    __module__ = 'pyobs.interfaces'
 
-    def move_altaz(self, alt: float, az: float, **kwargs: Any) -> None:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def move_altaz(self, alt: float, az: float, **kwargs: Any) -> None:
         """Moves to given coordinates.
 
         Args:
@@ -17,15 +20,16 @@ class IPointingAltAz(Interface):
         Raises:
             ValueError: If device could not move.
         """
-        raise NotImplementedError
+        ...
 
-    def get_altaz(self, **kwargs: Any) -> Tuple[float, float]:
+    @abstractmethod
+    async def get_altaz(self, **kwargs: Any) -> Tuple[float, float]:
         """Returns current Alt and Az.
 
         Returns:
             Tuple of current Alt and Az in degrees.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IPointingAltAz']
+__all__ = ["IPointingAltAz"]
