@@ -1,4 +1,5 @@
 import logging
+from abc import ABCMeta
 from typing import List, Dict, Tuple, Any, Optional
 
 from pyobs.interfaces import IDome
@@ -8,15 +9,18 @@ from .baseroof import BaseRoof
 log = logging.getLogger(__name__)
 
 
-class BaseDome(IDome, BaseRoof):
+class BaseDome(IDome, BaseRoof, metaclass=ABCMeta):
     """Base class for domes."""
-    __module__ = 'pyobs.modules.roof'
+
+    __module__ = "pyobs.modules.roof"
 
     def __init__(self, **kwargs: Any):
         """Initialize a new base dome."""
         BaseRoof.__init__(self, **kwargs)
 
-    def get_fits_header_before(self, namespaces: Optional[List[str]] = None, **kwargs: Any) -> Dict[str, Tuple[Any, str]]:
+    async def get_fits_header_before(
+        self, namespaces: Optional[List[str]] = None, **kwargs: Any
+    ) -> Dict[str, Tuple[Any, str]]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -27,12 +31,12 @@ class BaseDome(IDome, BaseRoof):
         """
 
         # get from parent
-        hdr = BaseRoof.get_fits_header_before(self, namespaces, **kwargs)
+        hdr = await BaseRoof.get_fits_header_before(self, namespaces, **kwargs)
 
         # add azimuth and return it
-        _, az = self.get_altaz()
-        hdr['ROOF-AZ'] = (az, 'Azimuth of roof slit, deg E of N')
+        _, az = await self.get_altaz()
+        hdr["ROOF-AZ"] = (az, "Azimuth of roof slit, deg E of N")
         return hdr
 
 
-__all__ = ['BaseDome']
+__all__ = ["BaseDome"]
