@@ -1,3 +1,4 @@
+from typing import Any
 import pandas as pd
 import logging
 
@@ -8,18 +9,18 @@ log = logging.getLogger(__name__)
 
 
 class CsvPublisher(Publisher):
-    def __init__(self, filename: str, *args, **kwargs):
+    def __init__(self, filename: str, **kwargs: Any):
         """Initialize new CSV publisher.
 
         Args:
             filename: Name of file to log in.
         """
-        Publisher.__init__(self, *args, **kwargs)
+        Publisher.__init__(self, **kwargs)
 
         # store
         self._filename = filename
 
-    def __call__(self, **kwargs):
+    async def __call__(self, **kwargs: Any) -> None:
         """Publish the given results.
 
         Args:
@@ -27,21 +28,27 @@ class CsvPublisher(Publisher):
         """
 
         # load data
-        try:
-            # load it
-            csv = self.vfs.read_csv(self._filename, index_col=False)
-
-        except FileNotFoundError:
-            # file not found, so start new with row
-            log.warning('No previous CSV file found, creating new one...')
-            csv = pd.DataFrame()
+        csv = self.data()
 
         # create new row from kwargs and append it
         row = pd.DataFrame(kwargs, index=[0])
         csv = pd.concat([csv, row], ignore_index=True)
 
         # write it
-        self.vfs.write_csv(csv, self._filename, index=False)
+        await self.vfs.write_csv(self._filename, csv, index=False)
+
+    async def data(self) -> pd.DataFrame:
+        """Return data that has so far been published."""
+
+        # load data
+        try:
+            # load it
+            return await self.vfs.read_csv(self._filename, index_col=False)
+
+        except FileNotFoundError:
+            # file not found, so start new with row
+            log.warning("No previous CSV file found, creating new one...")
+            return pd.DataFrame()
 
 
-__all__ = ['CsvPublisher']
+__all__ = ["CsvPublisher"]
