@@ -1,15 +1,16 @@
 import fnmatch
-from io import FileIO
 import os
+from typing import Any, Optional, Iterator, BinaryIO, IO, AnyStr, cast
 
-from .vfs import VFSFile
+from .file import VFSFile
 
 
-class LocalFile(VFSFile, FileIO):
+class LocalFile(VFSFile):
     """Wraps a local file with the virtual file system."""
-    __module__ = 'pyobs.vfs'
 
-    def __init__(self, name: str, mode: str = 'r', root: str = None, mkdir: bool = True, *args, **kwargs):
+    __module__ = "pyobs.vfs"
+
+    def __init__(self, name: str, mode: str = "r", root: Optional[str] = None, mkdir: bool = True, **kwargs: Any):
         """Open a local file.
 
         Args:
@@ -21,11 +22,11 @@ class LocalFile(VFSFile, FileIO):
 
         # no root given?
         if root is None:
-            raise ValueError('No root directory given.')
+            raise ValueError("No root directory given.")
 
         # filename is not allowed to start with a / or contain ..
-        if name.startswith('/') or '..' in name:
-            raise ValueError('Only files within root directory are allowed.')
+        if name.startswith("/") or ".." in name:
+            raise ValueError("Only files within root directory are allowed.")
 
         # build filename
         self.filename = name
@@ -37,13 +38,27 @@ class LocalFile(VFSFile, FileIO):
             if mkdir:
                 os.makedirs(path)
             else:
-                raise ValueError('Cannot write into sub-directory with disabled mkdir option.')
+                raise ValueError("Cannot write into sub-directory with disabled mkdir option.")
 
-        # init FileIO
-        FileIO.__init__(self, full_path, mode)
+        # file object
+        self.fd: IO[Any] = open(full_path, mode)
+
+    async def close(self) -> None:
+        if self.fd:
+            self.fd.close()
+
+    async def read(self, n: int = -1) -> AnyStr:
+        if self.fd is None:
+            raise OSError
+        return cast(AnyStr, self.fd.read(n))
+
+    async def write(self, s: AnyStr) -> None:
+        if self.fd is None:
+            raise OSError
+        self.fd.write(s)
 
     @staticmethod
-    def find(path: str, pattern: str, root: str = None, *args, **kwargs) -> list:
+    def find(path: str, pattern: str, root: str = "", *args: Any, **kwargs: Any) -> Iterator[str]:
         """Find files by pattern matching.
 
         Args:
@@ -64,7 +79,7 @@ class LocalFile(VFSFile, FileIO):
                 yield os.path.relpath(os.path.join(cur, filename), root)
 
     @staticmethod
-    def exists(path: str, root: str = None, *args, **kwargs) -> bool:
+    def exists(path: str, root: str = "", *args: Any, **kwargs: Any) -> bool:
         """Checks, whether a given path or file exists.
 
         Args:
@@ -82,4 +97,4 @@ class LocalFile(VFSFile, FileIO):
         return os.path.exists(full_path)
 
 
-__all__ = ['LocalFile']
+__all__ = ["LocalFile"]
